/*!
    \file   df_setup_records.h
    \author Bernd Ottmann
    \date   21.02.2003
    \brief  Deklarationen für die Funktionen der Setupdatensätze.
*/
#ifndef DF_SETUP_RECORDS_H
#define DF_SETUP_RECORDS_H

#include "df_defines.h"

/*! 
    \brief Datenzeiger ruecksetzen.

    Die Datenzeiger im Geraet werden rueckgesetzt. Die im Geraet eventuell enthaltenen  
    Datensaetze werden dadurch geloescht. 

    \param connectionId Kommunikationskanalnummer.
    \param deviceAddress Busnummer des anzusprechenden Geraetes.

    \return Ergebnis der Ausfuehrung.
    \retval 0 Funktion konnte nicht ausgefuehrt werden.
    \retval 1 Funktion wurde erfolgreich ausgefuehrt.

    \version Ab DLL - Version 2.0.0 enthalten.
*/
DF_API_EXTERN int DF_API_CALL DFCComClearData( int connectionId, int deviceAddress );


/*! 
    \brief Daten aus Geraet lesen.

    Es wird versucht die Daten aus dem Geraet in die DLL zu uebertragen. 

    \param connectionId Kommunikationskanalnummer.
    \param deviceAddress Busnummer des anzusprechenden Geraetes.
    \param errorNumber Zeiger auf Variable die nach Fehler den Fehlercode erhaelt.

    \return Ergebnis der Ausfuehrung.
    \retval 0 Funktion konnte nicht ausgefuehrt werden.
    \retval 1 Funktion wurde erfolgreich ausgefuehrt.

    \note Ab DLL - Version 2.0.0 satzweise lesen.
*/
DF_API_EXTERN int DF_API_CALL DFCComCollectData( int connectionId, int deviceAddress, int *errorNumber );


/*! 
    \brief Datensatz aus DLL / Geraet lesen.

    Es wird versucht einen Datensatz aus der DLL / oder Geraet an den Aufrufer zu  
    uebergeben. Die Busnummer ist durch vorherigen Aufruf der Funktion DFCComCollectData()
    bekannt.

    \param connectionId Kommunikationskanalnummer.
    \param buffer Zeiger auf den Puffer, welcher die Daten eines Datensatzes erhaelt.
    \param bufferSize Zeiger auf Variable welche die Datensatzlaenge erhaelt.
    \param errorNumber Zeiger auf Variable die nach Fehler den Fehlercode erhaelt.

    \return Ergebnis der Ausfuehrung.
    \retval 0 Funktion konnte nicht ausgefuehrt werden.
    \retval 1 Funktion wurde erfolgreich ausgefuehrt.

    \note Ab DLL - Version 2.0.0 satzweise lesen.
*/
DF_API_EXTERN int DF_API_CALL DFCComGetDatensatz( int connectionId, unsigned char *buffer, int *bufferSize, int *errorNumber );

#if (DF_API_VERSION >= 1)


/*! 
    \brief Tabellenbeschreibungen fuer Datensaetze aus Geraet lesen.

    Es wird versucht die Tabellenbeschreibungen aus dem Geraet zu lesen. Hiernach koennen   
    mit den Funktionen DFCDatBCnt(), DFCDatBDatensatz() und DFCDatBFeld() auf den 
    ermittelten Daten gearbeitet werden.

    \param connectionId Kommunikationskanalnummer.
    \param deviceAddress Busnummer des anzusprechenden Geraetes.
    \param errorNumber Zeiger auf Variable die nach Fehler den Fehlercode erhaelt.

    \return Ergebnis der Ausfuehrung.
    \retval 0 Funktion konnte nicht ausgefuehrt werden.
    \retval 1 Funktion wurde erfolgreich ausgefuehrt.

    \version Ab DLL - Version 1.1.i enthalten.
*/
DF_API_EXTERN int DF_API_CALL DFCLoadDatensatzbeschreibung( int connectionId, int deviceAddress, int *errorNumber );


/*! 
    \brief Anzahl der Tabellenbeschreibungen fuer Datensaetze ermitteln.

    Auf Grundlage der zuvor mit DFCLoadDatensatzbeschreibung() gelesenen Daten, wird 
    die Anzahl der definierten Tabellen zurueckgegeben.

    \param connectionId Kommunikationskanalnummer.

    \return Anzahl der mit DFCLoadDatensatzbeschreibung() gelesenen Tabellendefinitionen.

    \version Ab DLL - Version 1.1.i enthalten.
*/
DF_API_EXTERN int DF_API_CALL DFCDatBCnt( int connectionId );


/*! 
    \brief Grunddaten einer Tabellenbeschreibungen fuer Datensaetze ermitteln.

    Auf Grundlage der zuvor mit DFCLoadDatensatzbeschreibung() gelesenen Daten, werden 
    die Grunddaten zu einer Tabellen zurueckgegeben.

    \param connectionId Kommunikationskanalnummer.
    \param number Tabellennummer im Bereich von (0 - (DFCDatBCnt() - 1)).
    \param name Zeiger auf Speicherbereich fuer Tabellenname. (Mindestens 17 Zeichen).
    \param fieldCount Zeiger auf Variable, welche die Feldanzahl der Tabelle erhaelt.

    \return Ergebnis der Ausfuehrung.
    \retval 0 Funktion konnte nicht ausgefuehrt werden. (Tabelle nicht definiert!)
    \retval 1 Funktion wurde erfolgreich ausgefuehrt.

    \version Ab DLL - Version 1.1.i enthalten.
*/
DF_API_EXTERN int DF_API_CALL DFCDatBDatensatz( int connectionId, int number, unsigned char *name, int *fieldCount );


/*! 
    \brief Grunddaten eines Tabellenfeldes fuer Datensaetze ermitteln.

    Auf Grundlage der zuvor mit DFCLoadDatensatzbeschreibung() gelesenen Daten, werden 
    die Grunddaten zu einem Tabellenfeld zurueckgegeben.

    \param connectionId Kommunikationskanalnummer.
    \param datBNumber Tabellennummer im Bereich von (0 - (DFCDatBCnt() - 1)).
    \param number Feldnummer.
    \param name Zeiger auf Speicherbereich fuer Feldname. (Mindestens 17 Zeichen).
    \param type Zeiger auf Variable, welche den Feldtyp erhaelt.
    \param size Zeiger auf Variable, welche die definierte Laenge des Feldes erhaelt,
                    in dieser ist auch das Nullterminierungszeichen enthalten.

    \return Ergebnis der Ausfuehrung.
    \retval 0 Funktion konnte nicht ausgefuehrt werden. (Tabelle nicht definiert!)
    \retval 1 Funktion wurde erfolgreich ausgefuehrt.

    \version Ab DLL - Version 1.1.i enthalten.
*/
DF_API_EXTERN int DF_API_CALL DFCDatBFeld( int connectionId, int datBNumber, int number, unsigned char *name, int *type, int *size );

#endif

#if (DF_API_VERSION >= 0x02002300)


DF_API_EXTERN int DF_API_CALL DFCReadRecord( int channelID, int deviceAddress, char *buffer, int *bufferSize, int *errorNumber );

DF_API_EXTERN int DF_API_CALL DFCQuitRecord( int channelID, int deviceAddress, int *errorNumber );

DF_API_EXTERN int DF_API_CALL DFCRestoreRecords( int connectionId, int deviceAddress, int *errorNumber );

#endif

// ########################################################
// #############* PRIVATE FUNKTIONEN* #################
// ########################################################

// Funktionen sind nicht dokumentiert.
// Sie werden von AESetup oder Talk verwendet.
// Unterliegen evntl. Aenderungen.

#if defined( USE_PRIVATE )

#if (DF_API_VERSION >= 0x02000400)

DF_API_EXTERN int DF_API_CALL DFCCheckData( int connectionId, int deviceAddress, int *errorNumber );

#endif

#endif // USE_PRIVATE

#endif
